Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/lps35hw_simpletest.py
    :caption: examples/lps35hw_simpletest.py
    :linenos:

Relative Pressure
-----------------

Set the current pressure as zero hPa and make measurements relative to that pressure, even negative

.. literalinclude:: ../examples/lps35hw_relative.py
    :caption: examples/lps35hw_relative.py
    :linenos:

Threshold Setting
-----------------

Setting the pressure threshold to act as a trigger

.. literalinclude:: ../examples/lps35hw_high_threshold.py
    :caption: examples/lps35hw_high_threshold.py
    :linenos:

Using Filter
------------

Using the filter parameter to filter out high-frequency noise

.. literalinclude:: ../examples/lps35hw_filter.py
    :caption: examples/lps35hw_filter.py
    :linenos:

Data Rate
---------

Data rate example

.. literalinclude:: ../examples/lps35hw_data_rate.py
    :caption: examples/lps35hw_data_rate.py
    :linenos:
